//
//  WaveLayer.m
//  LayerContentAnimation
//
//  Created by Timothy J. Wood on 11/13/08.
//  Copyright 2008 The Omni Group. All rights reserved.
//

#import "WaveLayer.h"


@implementation WaveLayer
@dynamic phase, frequency, amplitude;

+ (NSSet *)keyPathsForValuesAffectingContent;
{
    static NSSet *keys = nil;
    if (!keys)
        keys = [[NSSet alloc] initWithObjects:@"phase", @"frequency", @"amplitude", nil];
    return keys;
}

- (void)drawInContext:(CGContextRef)ctx;
{
    CGRect bounds = self.bounds;
    
    CGContextTranslateCTM(ctx, CGRectGetWidth(bounds)/2.0, CGRectGetHeight(bounds)/2.0);
    CGColorRef color = CGColorCreateGenericRGB(1.0, 0.2, 0.2, 1.0);
    CGContextSetStrokeColorWithColor(ctx, color);
    CFRelease(color);
    
    CGContextSetLineWidth(ctx, 3);

    // Parameters
    CGFloat amplitude = CurrentAnimationValue(amplitude);
    CGFloat frequency = CurrentAnimationValue(frequency);
    CGFloat phase = CurrentAnimationValue(phase);
          
    // Lame curve drawing; whatever.
    unsigned int stepIndex, stepCount = CGRectGetWidth(bounds);
    for (stepIndex = 0; stepIndex < stepCount; stepIndex++) {
        CGFloat x = -CGRectGetWidth(bounds)/2.0 + stepIndex*CGRectGetWidth(bounds)/stepCount;
        CGFloat y = amplitude * sin(x*frequency + phase);
        
        if (stepIndex == 0)
            CGContextMoveToPoint(ctx, x, y);
        else
            CGContextAddLineToPoint(ctx, x, y);
    }
    
    CGContextStrokePath(ctx);
}

@end
